@@ -81,11 +81,21 @@ class Load(command.Command):
                             help='If set do not print stdout or stderr '
                             'attachment contents on a successful test '
                             'execution')
+        parser.add_argument('--all-attachments', action='store_true',
+                            dest='all_attachments',
+                            help='If set print all text attachment contents on'
+                            ' a successful test execution')
         return parser
 
     def take_action(self, parsed_args):
         user_conf = user_config.get_user_config(self.app_args.user_config)
         args = parsed_args
+        if args.suppress_attachments and args.all_attachments:
+            msg = ("The --suppress-attachments and --all-attachments "
+                   "options are mutually exclusive, you can not use both "
+                   "at the same time")
+            print(msg)
+            sys.exit(1)
         if getattr(user_conf, 'load', False):
             force_init = args.force_init or user_conf.load.get('force-init',
                                                                False)
@@ -94,15 +104,26 @@ class Load(command.Command):
             color = args.color or user_conf.load.get('color', False)
             abbreviate = args.abbreviate or user_conf.load.get('abbreviate',
                                                                False)
-            suppress_attachments = (
-                args.suppress_attachments or user_conf.load.get(
-                    'suppress-attachments', False))
+            suppress_attachments_conf = user_conf.run.get(
+                'suppress-attachments', False)
+            all_attachments_conf = user_conf.run.get(
+                'all-attachments', False)
+            if not args.suppress_attachments and not args.all_attachments:
+                suppress_attachments = suppress_attachments_conf
+                all_attachments = all_attachments_conf
+            elif args.suppress_attachments:
+                all_attachments = False
+                suppress_attachments = args.suppress_attachments
+            elif args.all_attachments:
+                suppress_attachments = False
+                all_attachments = args.all_attachments
         else:
             force_init = args.force_init
             pretty_out = args.subunit_trace
             color = args.color
             abbreviate = args.abbreviate
             suppress_attachments = args.suppress_attachments
+            all_attachments = args.all_attachments
         verbose_level = self.app.options.verbose_level
         stdout = open(os.devnull, 'w') if verbose_level == 0 else sys.stdout
         load(repo_type=self.app_args.repo_type,
@@ -111,14 +132,15 @@ class Load(command.Command):
              force_init=force_init, streams=args.files,
              pretty_out=pretty_out, color=color,
              stdout=stdout, abbreviate=abbreviate,
-             suppress_attachments=suppress_attachments, serial=True)
+             suppress_attachments=suppress_attachments, serial=True,
+             all_attachments=all_attachments)
 
 
 def load(force_init=False, in_streams=None,
          partial=False, subunit_out=False, repo_type='file', repo_url=None,
          run_id=None, streams=None, pretty_out=False, color=False,
          stdout=sys.stdout, abbreviate=False, suppress_attachments=False,
-         serial=False):
+         serial=False, all_attachments=False):
     """Load subunit streams into a repository
 
     This function will load subunit streams into the repository. It will
@@ -147,6 +169,8 @@ def load(force_init=False, in_streams=None,
     :param bool abbreviate: Use abbreviated output if set true
     :param bool suppress_attachments: When set true attachments subunit_trace
         will not print attachments on successful test execution.
+    :param bool all_attachments: When set true subunit_trace will print all
+        text attachments on successful test execution.
 
     :return return_code: The exit code for the command. 0 for success and > 0
         for failures.
@@ -198,7 +222,7 @@ def load(force_init=False, in_streams=None,
                 stream, non_subunit_name='stdout')
             result = _load_case(inserter, repo, case, subunit_out, pretty_out,
                                 color, stdout, abbreviate,
-                                suppress_attachments)
+                                suppress_attachments, all_attachments)
             if result or retval:
                 retval = 1
             else:
@@ -206,13 +230,15 @@ def load(force_init=False, in_streams=None,
     else:
         case = testtools.ConcurrentStreamTestSuite(make_tests)
         retval = _load_case(inserter, repo, case, subunit_out, pretty_out,
-                            color, stdout, abbreviate, suppress_attachments)
+                            color, stdout, abbreviate, suppress_attachments,
+                            all_attachments)
 
     return retval
 
 
 def _load_case(inserter, repo, case, subunit_out, pretty_out,
-               color, stdout, abbreviate, suppress_attachments):
+               color, stdout, abbreviate, suppress_attachments,
+               all_attachments):
     if subunit_out:
         output_result, summary_result = output.make_result(inserter.get_id,
                                                            output=stdout)
@@ -220,7 +246,8 @@ def _load_case(inserter, repo, case, subunit_out, pretty_out,
         outcomes = testtools.StreamToDict(
             functools.partial(subunit_trace.show_outcome, stdout,
                               enable_color=color, abbreviate=abbreviate,
-                              suppress_attachments=suppress_attachments))
+                              suppress_attachments=suppress_attachments,
+                              all_attachments=all_attachments))
         summary_result = testtools.StreamSummary()
         output_result = testtools.CopyStreamResult([outcomes, summary_result])
         output_result = testtools.StreamResultRouter(output_result)
@@ -244,10 +271,14 @@ def _load_case(inserter, repo, case, subunit_out, pretty_out,
         start_times = []
         stop_times = []
         for worker in subunit_trace.RESULTS:
-            start_times += [
-                x['timestamps'][0] for x in subunit_trace.RESULTS[worker]]
-            stop_times += [
-                x['timestamps'][1] for x in subunit_trace.RESULTS[worker]]
+            for test in subunit_trace.RESULTS[worker]:
+                if not test['timestamps'][0] or not test['timestamps'][1]:
+                    continue
+                start_times.append(test['timestamps'][0])
+                stop_times.append(test['timestamps'][1])
+        if not start_times or not stop_times:
+            sys.stderr.write("\nNo tests were successful during the run")
+            return 1
         start_time = min(start_times)
         stop_time = max(stop_times)
         elapsed_time = stop_time - start_time
